Microsoft Azure IoTHub client libraries

Dependents:   sht15_remote_monitoring RobotArmDemo iothub_client_sample_amqp f767zi_mqtt ... more

This library implements the Microsoft Azure IoTHub client library. The code is replicated from https://github.com/Azure/azure-iot-sdks

Revision:
10:38383e246675
Parent:
9:3ec7e2695f98
--- a/iothub_client.h	Tue Sep 22 20:36:48 2015 -0700
+++ b/iothub_client.h	Sat Sep 26 00:18:01 2015 -0700
@@ -32,10 +32,10 @@
 	*
 	*			Sample connection string:
 	*				<blockquote>
-	*					<pre>HostName=[IoT Hub name goes here].[IoT Hub suffix goes here, e.g., private.azure-devices-int.net];DeviceId= [Device ID goes here];SharedAccessKey= [Device key goes here];</pre>
+	*					<pre>HostName=[IoT Hub name goes here].[IoT Hub suffix goes here, e.g., private.azure-devices-int.net];DeviceId=[Device ID goes here];SharedAccessKey=[Device key goes here];</pre>
 	*				</blockquote>
 	*
 	* @return	A non-NULL @c IOTHUB_CLIENT_LL_HANDLE value that is used when
 	* 			invoking other functions for IoT Hub client and @c NULL on failure.
 	*/
     extern IOTHUB_CLIENT_HANDLE IoTHubClient_CreateFromConnectionString(const char* connectionString, IOTHUB_CLIENT_TRANSPORT_PROVIDER protocol);
@@ -49,7 +49,7 @@
 	*			The API does not allow sharing of a connection across multiple
 	*			devices. This is a blocking call.
 	*
 	* @return	A non-NULL @c IOTHUB_CLIENT_LL_HANDLE value that is used when
 	* 			invoking other functions for IoT Hub client and @c NULL on failure.
 	*/
     extern IOTHUB_CLIENT_HANDLE IoTHubClient_Create(const IOTHUB_CLIENT_CONFIG* config);
@@ -70,7 +70,7 @@
 	* @param	eventConfirmationCallback  	The callback specified by the device for receiving
 	* 										confirmation of the delivery of the IoT Hub message.
 	* 										This callback can be expected to invoke the
-	* 										::IoTHubClient_LL_SendEventAsync function for the
+	* 										::IoTHubClient_SendEventAsync function for the
 	* 										same message in an attempt to retry sending a failing
 	* 										message. The user can specify a @c NULL value here to
 	* 										indicate that no callback is required.
@@ -78,7 +78,7 @@
 	* 										callback. This can be @c NULL.
 	*
 	*			@b NOTE: The application behavior is undefined if the user calls
-	*			the ::IoTHubClient_LL_Destroy function from within any callback.
+	*			the ::IoTHubClient_Destroy function from within any callback.
 	*
 	* @return	IOTHUB_CLIENT_OK upon success or an error code upon failure.
 	*/
@@ -96,7 +96,7 @@
 	*
 	* @return	IOTHUB_CLIENT_OK upon success or an error code upon failure.
 	*/
-    extern IOTHUB_CLIENT_RESULT IoTHubClient_GetSendStatus(IOTHUB_CLIENT_LL_HANDLE iotHubClientHandle, IOTHUB_CLIENT_STATUS *iotHubClientStatus);
+    extern IOTHUB_CLIENT_RESULT IoTHubClient_GetSendStatus(IOTHUB_CLIENT_HANDLE iotHubClientHandle, IOTHUB_CLIENT_STATUS *iotHubClientStatus);
 
 	/**
 	* @brief	Sets up the message callback to be invoked when IoT Hub issues a
@@ -109,7 +109,7 @@
 	* 										callback. This can be @c NULL.
 	*
 	*			@b NOTE: The application behavior is undefined if the user calls
-	*			the ::IoTHubClient_LL_Destroy function from within any callback.
+	*			the ::IoTHubClient_Destroy function from within any callback.
 	*
 	* @return	IOTHUB_CLIENT_OK upon success or an error code upon failure.
 	*/
@@ -32,10 +32,10 @@
 	*				</blockquote>
 	*
-	* @return	A non-NULL @c IOTHUB_CLIENT_LL_HANDLE value that is used when
+	* @return	A non-NULL @c IOTHUB_CLIENT_HANDLE value that is used when
 	* 			invoking other functions for IoT Hub client and @c NULL on failure.
 	*/
@@ -49,7 +49,7 @@
 	*			devices. This is a blocking call.
 	*
-	* @return	A non-NULL @c IOTHUB_CLIENT_LL_HANDLE value that is used when
+	* @return	A non-NULL @c IOTHUB_CLIENT_HANDLE value that is used when
 	* 			invoking other functions for IoT Hub client and @c NULL on failure.
 	*/